@@ -56,7 +56,7 @@ bool BadgeData::getTimetable(TimeTable &tt)
     return false;
 }
 
-QTime BadgeData::totalTime(QDate begin, QDate end)
+int BadgeData::totalTime(QDate begin, QDate end)
 {
     QFile data;
     TimeTable dum;
@@ -82,12 +82,12 @@ QTime BadgeData::totalTime(QDate begin, QDate end)
                 totalInSeconds -= dum.secondPause.secsTo(dum.endSecondPause);
             }
 
-
+                //qDebug() << "TOT SEC = " << totalInSeconds << endl;
 
         }
 
     }
     data.close();
-    total.setHMS((int)(totalInSeconds / 3600), (int) ((totalInSeconds % 3600) / 60), 0);
-    return total;
+    //total.setHMS((int)(totalInSeconds / 3600), (int) ((totalInSeconds % 3600) / 60), 0);
+    return totalInSeconds;
 }
