@@ -11,7 +11,7 @@ public:
     BadgeData();
     bool setTimetable(TimeTable in);
     bool getTimetable(TimeTable &out);
-    QTime totalTime(QDate begin, QDate end);
+    int totalTime(QDate begin, QDate end);
 };
 
 #endif // BADGEDATA_H
