@@ -29,7 +29,7 @@ class DialogSearch : public QDialog {
 public:
     DialogSearch(QWidget *parent = 0);
     ~DialogSearch();
-    QTime totalHours(bool &ok);
+    int totalHours(bool &ok);
 protected:
     void changeEvent(QEvent *e);
 
